diff --git a/src/winio.c b/src/winio.c
index 2381b6f870fda5776fb8ef6550ca79207ebc5eac..50eb5a23a2325b7b648c1dff1917a95d85995ae0 100644
--- a/src/winio.c
+++ b/src/winio.c
@@ -316,9 +316,9 @@ int get_kbinput(WINDOW *win, bool *meta_key, bool *func_key)
      * we get a recognized value or sequence. */
     while ((kbinput = parse_kbinput(win, meta_key, func_key)) == ERR);
 
-    /* If we didn't read from the statusbar prompt, blank the statusbar
-     * if we need to. */
-    if (win != bottomwin)
+    /* If we read from the edit window, blank the statusbar if we need
+     * to. */
+    if (win == edit)
 	check_statusblank();
 
     return kbinput;